@@ -6,7 +6,7 @@ use fixed_bit_string::FixedBitString;
 ///
 /// Created by
 /// [`FixedBitString::iter()`](trait.FixedBitString.html#method.iter).
-#[derive(Clone,Debug)]
+#[derive(Clone, Debug)]
 pub struct Iter<B> {
 	next: Option<B>,
 	prefix: usize,
@@ -16,14 +16,14 @@ impl<B: FixedBitString> Iter<B> {
 	#[doc(hidden)]
 	// internal use only, will become pub(crate)
 	pub fn new(start: B, prefix: usize) -> Self {
-		Iter{
+		Iter {
 			next: Some(start),
-			prefix: prefix,
+			prefix,
 		}
 	}
 }
 
-impl<B: FixedBitString+Clone> Iterator for Iter<B> {
+impl<B: FixedBitString + Clone> Iterator for Iter<B> {
 	type Item = B;
 
 	fn next(&mut self) -> Option<Self::Item> {
@@ -34,7 +34,7 @@ impl<B: FixedBitString+Clone> Iterator for Iter<B> {
 				let result = Some(next.clone());
 				overflow = next.inc(self.prefix);
 				result
-			}
+			},
 		};
 		if overflow {
 			self.next = None;
