@@ -1,7 +1,9 @@
 //! contains everything related to the `FixedBitString` trait.
 
-pub use self::iter::*;
-pub use self::traits::*;
+pub use self::{
+	iter::*,
+	traits::*,
+};
 
 mod iter;
 mod traits;
